@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use Carp ();
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use base qw(Module::Install::Base);
 
@@ -18,7 +18,10 @@ sub prepan {
     my ($self, %args) = @_;
     my @invalid_keys = grep { !$SCHEMA{$_} } keys %args;
     Carp::croak "invalid keys: " . join ', ', @invalid_keys if @invalid_keys;
-    $self->resources(X_prepan => \%args);
+    $self->resources(
+        X_prepan_author => $args{author_url},
+        X_prepan_module => $args{module_url},
+    );
 }
 
 !!1;
@@ -27,4 +30,4 @@ __END__
 
 =encoding utf8
 
-#line 84
+#line 87
